
From: Dmitry Torokhov <dtor_core@ameritech.net>

With Vojtech's approval adjusted i8042 option names by dropping i8042_
prefix.

If i8042 is compiled as a module new option names are: direct, dumbkbd,
noaux, nomux, reset, unlock.

If i8042 is build in the kernel the prefix "i8042." is required in front of
an option, like "i8042.reset"



 Documentation/kernel-parameters.txt |   16 +++++++++-------
 drivers/input/serio/i8042.c         |   18 ++++++++++++------
 2 files changed, 21 insertions(+), 13 deletions(-)

diff -puN Documentation/kernel-parameters.txt~input-02-i8042-option-parsing Documentation/kernel-parameters.txt
--- 25/Documentation/kernel-parameters.txt~input-02-i8042-option-parsing	2004-01-03 01:13:42.000000000 -0800
+++ 25-akpm/Documentation/kernel-parameters.txt	2004-01-03 01:13:42.000000000 -0800
@@ -372,13 +372,15 @@ running once the system is up.
 
 	noirqbalance	[IA-32,SMP,KNL] Disable kernel irq balancing
 
-	i8042_direct	[HW] Keyboard has been put into non-translated mode 
-			by BIOS
-	i8042_dumbkbd	[HW] Don't attempt to blink the leds
-	i8042_noaux	[HW] Don't check for auxiliary (== mouse) port
-	i8042_nomux
-	i8042_reset	[HW] Reset the controller during init and cleanup
-	i8042_unlock	[HW] Unlock (ignore) the keylock
+	i8042.direct	[HW] Put keyboard port into non-translated mode
+	i8042.dumbkbd	[HW] Pretend that controlled can only read data from
+			     keyboard and can not control its state
+			     (Don't attempt to blink the leds)
+	i8042.noaux	[HW] Don't check for auxiliary (== mouse) port
+	i8042.nomux	[HW] Don't check presence of an active multiplexing
+			     controller
+	i8042.reset	[HW] Reset the controller during init and cleanup
+	i8042.unlock	[HW] Unlock (ignore) the keylock
 
 	i810=		[HW,DRM]
 
diff -puN drivers/input/serio/i8042.c~input-02-i8042-option-parsing drivers/input/serio/i8042.c
--- 25/drivers/input/serio/i8042.c~input-02-i8042-option-parsing	2004-01-03 01:13:42.000000000 -0800
+++ 25-akpm/drivers/input/serio/i8042.c	2004-01-03 01:13:42.000000000 -0800
@@ -29,22 +29,28 @@ MODULE_DESCRIPTION("i8042 keyboard and m
 MODULE_LICENSE("GPL");
 
 static unsigned int i8042_noaux;
-module_param(i8042_noaux, bool, 0);
+module_param_named(noaux, i8042_noaux, bool, 0);
+MODULE_PARM_DESC(noaux, "Do not probe or use AUX (mouse) port.");
 
 static unsigned int i8042_nomux;
-module_param(i8042_nomux, bool, 0);
+module_param_named(nomux, i8042_nomux, bool, 0);
+MODULE_PARM_DESC(nomux, "Do not check whether an active multiplexing conrtoller is present.");
 
 static unsigned int i8042_unlock;
-module_param(i8042_unlock, bool, 0);
+module_param_named(unlock, i8042_unlock, bool, 0);
+MODULE_PARM_DESC(unlock, "Ignore keyboard lock.");
 
 static unsigned int i8042_reset;
-module_param(i8042_reset, bool, 0);
+module_param_named(reset, i8042_reset, bool, 0);
+MODULE_PARM_DESC(reset, "Reset controller during init and cleanup.");
 
 static unsigned int i8042_direct;
-module_param(i8042_direct, bool, 0);
+module_param_named(direct, i8042_direct, bool, 0);
+MODULE_PARM_DESC(direct, "Put keyboard port into non-translated mode.");
 
 static unsigned int i8042_dumbkbd;
-module_param(i8042_dumbkbd, bool, 0);
+module_param_named(dumbkbd, i8042_dumbkbd, bool, 0);
+MODULE_PARM_DESC(dumbkbd, "Pretend that controller can only read data from keyboard");
 
 #undef DEBUG
 #include "i8042.h"

_
